import {defineConfig} from 'vite'
import react from '@vitejs/plugin-react'
import viteTsconfigPaths from 'vite-tsconfig-paths';
import dayjs from 'dayjs'

import {AppConfig, BuildEnvName} from './config'
import AppPackage from './package.json'

// https://vitejs.dev/config/
export default defineConfig(({mode}) => {
	// const isDEV = mode === 'development' && BuildEnvName !== 'prod';
	if (BuildEnvName === 'prod' || mode == 'prod') mode = 'production';
	if (BuildEnvName === 'dev') mode = 'development';
	if (BuildEnvName === 'pre' || mode == 'pre') mode = 'preview';

	const APP_CONFIG = AppConfig[mode] || AppConfig.development
	APP_CONFIG.ENV_MODE = mode;
	console.log('mode=>', mode, 'BuildEnvName=>', BuildEnvName,APP_CONFIG)
	const AppVersion = {
		version: AppPackage.version,
		buildVersion: AppPackage.name + `-${mode}-` + dayjs().format('YYMMDDHH'),
		platform: 'unknown',
		platformVersion: AppPackage.version
	}

	return {
		plugins: [
			react(), viteTsconfigPaths(),
		],
		define: {
			AppVersion,
			APP_CONFIG
		},
		base: APP_CONFIG.PUBLIC_PATH,
		build: {
			sourcemap: mode !== 'production' ,
			// 小于100kb直接base64
			assetsInlineLimit: 102400,
			rollupOptions: {
				output: {
					manualChunks() {
						return 'app-libs';
					}
				}
			}
		},
		server: {
			proxy: {
				'/api': {
					target: "https://gm-plugin-fn.gachafun.com", // https://gm.gachafun.com http://gm.zverse.group http://192.168.0.231:9892 192.168.0.114:9892 pre-gm-plugin.gachafun.com
					changeOrigin: true,
					// rewrite: (path) => path.replace(/^\/api/, ""),
				}
			}
		}
	}
})
